/**********************************************************************************/
// Persistence of Vision Ray Tracer Scene Description File
// File name   : MH_clouds.pov
// Version     : 3.5/3.6
// Description : Problem: different render in 3.5 or 3.6.
//							 possible cause: noise_generator 3
// Date        : 13-06-2004     
// Author      : Mick Hazelgrove
// E-mail      : 
 
// Copyright (C) 2004. All rights reserved.
/**********************************************************************************/



#version 3.5;

#include "colors.inc"

global_settings
{
  assumed_gamma 1.0
  max_trace_level 120
  noise_generator 2  // was 3
   radiosity{
   pretrace_start 0.08
   pretrace_end   0.01
   count 10 // 10
   nearest_count 5
   error_bound 0.4
   recursion_limit 1
   low_error_factor 0.5
   gray_threshold 0
   minimum_reuse 0.015
   brightness .325
   adc_bailout 0.006
   normal on
     media on
  }
}

// ---------------------------------------- 


camera{
  location  <0.0, 0.5 , -25> //-25
  //location  <0.0, 65 , 0>
  direction z   //1.5*z
  right     image_width/image_height*x
  look_at   z*10000//<0.0, 1,  0.0>
  //look_at 0
  rotate y*-5
  angle 50//32
  translate y*1 //1500
}

sky_sphere{
  pigment {
   gradient y
   color_map { [0.0 SteelBlue+((White)/2)][0.75 SteelBlue*.75 ]}
    rotate x*-90
 }
}

light_source{<0,100000,0>
color rgb <1,.6,.125> *.875
rotate z*25 rotate x*50   // was z*25 try 30
media_interaction on media_attenuation off
}

plane { y, 0.0 pigment {color rgb <1,0.5,0>}}


  //media sky based on code by Juha Leppl

  #declare Rad = 8000;

  #macro SkyShell(minAlt, maxAlt, Int, Scle, Rot)
    difference {
     sphere {< 0, 0, 0>, 1 scale (Rad + maxAlt)}
     sphere {< 0, 0, 0>, 1 scale (Rad + minAlt)}

     texture {pigment {color rgbf 1}finish {ambient 0 diffuse 1}}
///****************Finish added???????????????????
     interior {Int}

       scale Scle
       rotate Rot
       translate -y*Rad
     hollow
    }
  #end //end macro

#declare HC =
  SkyShell(
    1000,1550, // high cloud
    interior {
      media {
        samples 5,10
        intervals 2
        scattering { 2, rgb <0.0075, 0.007, 0.0065>*.65 } //colour of base of clouds multiplyer controls darkness, smaller lighter
        density {
          wrinkles
            warp{turbulence 0.4 lambda 3 omega 0.6}
              scale Rad*.15
          color_map {
                  [0 rgb 0]
                  [0.125 rgb 0]
                  [0.38 rgb 0.5*.5]
                  [0.75 rgb 0.8*.5]
                  [1 rgb <1,1,0>*.5]
          }// cmap
          scale 1
        } //density
      } //media
    } //int
      <1,1,1>*3
      <-9,124,0>
  )

#declare LDC =
 SkyShell(    //low dark cloud
    300,900
    interior {
      media {  method 3
        samples 5,10
        intervals 2
        scattering { 2, rgb <0.0075*1.75, 0.00875*1.75, 0.007*1.75>*.75 }
        density {
          wrinkles
            warp { turbulence 0.5 lambda 2.3 omega 0.475 }
              scale Rad*.15
          color_map {
                  [0 rgb 0]
                  [0.4 rgb 0]
                  [0.5 rgb 0.75/3]
                  [0.95 rgb 1.5/3]
                  [1 rgb 1]
          }// cmap
          turbulence .5
          scale <2,.75,1>*.7
        } //density
      } //media
    } //int
    <-1.75,1.75,1.75>
    <45,54,0>
  )

#declare LSDC =
 SkyShell(    //low scudding dark cloud
    100,295
    interior {
      media {  method 3
        samples 5,10
        intervals 2
        scattering { 2, rgb <0.0075*1.75, 0.00875*1.75, 0.007*1.75>*2 }
        //scattering { 2, rgb <0.0075*1.75, 0.00875*1.75,0.007*1.75>*1.675 }
        density {
          wrinkles
            warp { turbulence 0.5 lambda 2.3 omega 0.475 }
              scale Rad*.15
          color_map {
                  [0 rgb 0]
                  [0.65 rgb 0]
                  [0.55 rgb 0.75/3]
                  [0.95 rgb 1.5/3]
                  [1 rgb 1]
          }// cmap
          scale <2,.75,1>*.7
        } //density
      } //media
    } //int
    <3,1.75,1.75>
    <-46.5,-43,0>
  )

object {HC}
object {LDC}
object {LSDC}
